@@ -67,7 +67,9 @@ ApplicationDTO = Union[IndividualApplicationDTO, BusinessApplicationDTO]
 
 class CreateIndividualApplicationRequest(UnitRequest):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, email: str, phone: Phone,
-                 ip: str = None, ein: str = None, dba: str = None, sole_proprietorship: bool = None, ssn = None):
+                 ip: str = None, ein: str = None, dba: str = None, sole_proprietorship: bool = None,
+                 passport: str = None, nationality: str = None, ssn = None,
+                 device_fingerprints: Optional[List[DeviceFingerprint]] = None):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
         self.address = address
@@ -78,6 +80,9 @@ class CreateIndividualApplicationRequest(UnitRequest):
         self.dba = dba
         self.sole_proprietorship = sole_proprietorship
         self.ssn = ssn
+        self.passport = passport
+        self.nationality = nationality
+        self.device_fingerprints = device_fingerprints
 
     def to_json_api(self) -> Dict:
         payload = {
@@ -108,6 +113,15 @@ class CreateIndividualApplicationRequest(UnitRequest):
         if self.ssn:
             payload["data"]["attributes"]["ssn"] = self.ssn
 
+        if self.passport:
+            payload["data"]["attributes"]["passport"] = self.passport
+
+        if self.nationality:
+            payload["data"]["attributes"]["nationality"] = self.nationality
+
+        if self.device_fingerprints:
+            payload["data"]["attributes"]["deviceFingerprints"] = [e.to_json_api() for e in self.device_fingerprints]
+
         return payload
 
     def __repr__(self):
